## $Id: payment.py 9992 2013-02-24 17:45:49Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Application fee payment.
"""
import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.kofa.applicants.payment import ApplicantOnlinePayment
from waeup.kofa.utils.helpers import attrs_to_fields
from waeup.kwarapoly.applicants.interfaces import ICustomApplicantOnlinePayment

class CustomApplicantOnlinePayment(ApplicantOnlinePayment):
    """This is a custom online payment for applicants.

    Since this class inherits from ApplicantOnlinePayment, it automatically
    implements the interfaces of the parent class which means
    all viewlets and views meant for StudentOnlinePayment
    can also be accessed in the customized system.
    """
    grok.implements(ICustomApplicantOnlinePayment)
    grok.provides(ICustomApplicantOnlinePayment)

    def __init__(self):
        super(CustomApplicantOnlinePayment, self).__init__()
        return

CustomApplicantOnlinePayment = attrs_to_fields(
    CustomApplicantOnlinePayment, omit=['display_item'])

# Applicant online payments must be importable. So we might need a factory.
class CustomApplicantOnlinePaymentFactory(grok.GlobalUtility):
    """A factory for applicant online payments.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.ApplicantOnlinePayment')
    title = u"Create a new online payment.",
    description = u"This factory instantiates new online payment instances."

    def __call__(self, *args, **kw):
        return CustomApplicantOnlinePayment()

    def getInterfaces(self):
        return implementedBy(CustomApplicantOnlinePayment)
